@@ -47,73 +47,47 @@ class CGImage_Resize_Filter extends CGImageFilterBase
   public function __construct(/* var args */)
   {
     $input = func_get_args();
-    if( count($input) == 1 && is_array($input[0]) )
-      {
-	$input = $input[0];
-      }
+    if( count($input) == 1 && is_array($input[0]) ) $input = $input[0];
 
-    if( cge_array::is_hash($input) )
-      {
-	if( isset($input['width']) )
-	  {
-	    $this->_width = (int)$input['width'];
-	  }
-	if( isset($input['height']) )
-	  {
-	    $this->_height = (int)$input['height'];
-	  }
-	if( isset($input['percent']) )
-	  {
-	    $this->_percent = (int)$input['percent'];
-	    $this->_percent = min(100,max(1,$this->_percent));
-	  }
-	if( isset($input['resample']) )
-	  {
-	    $this->_resample = (int)$input['resample'];
-	  }
-	if( isset($input['upscale']) )
-	  {
-	    $this->_upscale = (int)$input['upscale'];
-	  }
+    if( cge_array::is_hash($input) ) {
+      if( isset($input['width']) ) $this->_width = (int)$input['width'];
+      if( isset($input['height']) ) $this->_height = (int)$input['height'];
+      if( isset($input['percent']) ) {
+	$this->_percent = (int)$input['percent'];
+	$this->_percent = min(100,max(1,$this->_percent));
       }
-    else if( is_array($input) && count($input) >= 2 )
-      {
-	$idx = 2;
-	switch( $input[0] )
-	  {
-	  case 'p':
-	    $this->_percent = (int)$input[1];
-	    break;
-	  case 'w':
-	    $this->_width = (int)$input[1];
-	    break;
-	  case 'h':
-	    $this->_height = (int)$input[1];
-	    break;
-	  case 'e':
-	    $this->_edge = (int)$input[1];
-	  case 'c':
-	    $this->_width = (int)$input[1];
-	    $this->_height = (int)$input[2];
-	    $idx = 3;
-	    break;
-	  }
-
-	if( count($input) > $idx ) {
-	  $this->_upscale = (int)$input[$idx];
-	}
-      }
-
-    if( $this->_width > 0 ) {
-      $this->_width = cgsi_utils::trim_to_device('width',$this->_width);
+      if( isset($input['resample']) ) $this->_resample = (int)$input['resample'];
+      if( isset($input['upscale']) ) $this->_upscale = (int)$input['upscale'];
     }
-    if( $this->_height > 0 ) {
-      $this->_height = cgsi_utils::trim_to_device('height',$this->_height);
-    }
-    if( !($this->_percent > 0 || $this->_width > 0 || $this->_height > 0 || $this->_edge > 0) )
-      {
-	throw new Exception('Could not Create Resize Filter - Invalid Parameters');
+    else if( is_array($input) && count($input) >= 2 ) {
+      $idx = 2;
+      switch( $input[0] ) {
+      case 'p':
+	$this->_percent = (int)$input[1];
+	break;
+      case 'w':
+	$this->_width = (int)$input[1];
+	break;
+      case 'h':
+	$this->_height = (int)$input[1];
+	break;
+      case 'e':
+	$this->_edge = (int)$input[1];
+      case 'c':
+	$this->_width = (int)$input[1];
+	$this->_height = (int)$input[2];
+	$idx = 3;
+	break;
       }
+
+      if( count($input) > $idx ) $this->_upscale = (int)$input[$idx];
+    }
+
+    if( $this->_width > 0 ) $this->_width = cgsi_utils::trim_to_device('width',$this->_width);
+    if( $this->_height > 0 ) $this->_height = cgsi_utils::trim_to_device('height',$this->_height);
+    if( !($this->_percent > 0 || $this->_width > 0 || $this->_height > 0 || $this->_edge > 0) ) {
+      throw new Exception('Could not Create Resize Filter - Invalid Parameters');
+    }
   }
 
 
@@ -129,16 +103,13 @@ class CGImage_Resize_Filter extends CGImageFilterBase
     $_dest = new CGImageBase(array($src['type'],$new_w,$new_h));
 
     $res = '';
-    if( $this->_resample )
-      {
-	$res = imagecopyresampled($_dest['rsrc'],$src['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
-      }
-    else
-      {
-	$res = imagecopyresized($_dest['rsrc'],$src['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
-      }
-    if( !$res )
-      throw new Exception('Image Transform Failed');
+    if( $this->_resample ) {
+      $res = imagecopyresampled($_dest['rsrc'],$src['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
+    }
+    else {
+      $res = imagecopyresized($_dest['rsrc'],$src['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
+    }
+    if( !$res ) throw new Exception('Image Transform Failed');
 
     return $_dest;
   }
@@ -196,27 +167,23 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 
   public function transform(CGImageBase $img)
   {
-    if( $this->_percent > 0 )
-      {
-	// percentage resize.
-	return $this->_transform_percentage($img);
-      }
-      if($this->_edge > 0 && ($img['width'] > $this->_edge || $img['height'] > $this->_edge)){
+    if( $this->_percent > 0 ) {
+      // percentage resize.
+      return $this->_transform_percentage($img);
+    }
+    if($this->_edge > 0 && ($img['width'] > $this->_edge || $img['height'] > $this->_edge)){
       //resize by longest edge
-       return $this->_transform_edge($img);
-      }
-    if( $this->_width > 0 && $this->_height == 0 && $img['width'] > $this->_width )
-      { 
-	return $this->_transform_width($img);
-      }
-    if( $this->_width == 0 && $this->_height > 0 && $img['height'] > $this->_height )
-      {
-	return $this->_transform_height($img);
-      }
-    if( $this->_width > 0 && $this->_height > 0 && $img['width'] > $this->_width && $img['height'] > $this->_height )
-      {
-	return $this->_transform_custom($img);
-      }
+      return $this->_transform_edge($img);
+    }
+    if( $this->_width > 0 && $this->_height == 0 && $img['width'] > $this->_width ) {
+      return $this->_transform_width($img);
+    }
+    if( $this->_width == 0 && $this->_height > 0 && $img['height'] > $this->_height ) {
+      return $this->_transform_height($img);
+    }
+    if( $this->_width > 0 && $this->_height > 0 && $img['width'] > $this->_width && $img['height'] > $this->_height ) {
+      return $this->_transform_custom($img);
+    }
     // nothing to do.... but trick the image to be dirty.
     $img['height'] = $img['height'];
     return $img;
@@ -226,4 +193,4 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
