@@ -49,71 +49,52 @@ class CGImage_Resizetofit_Filter extends CGImageFilterBase
   {
     $mod = cms_utils::get_module('CGSmartImage');
     $this->_loc = $mod->GetPreference('croptofit_default_loc','c');
-    if( cge_array::is_hash($input) )
-      {
-	if( isset($input['width']) )
-	  {
-	    $this->_dest_w = (int)$input['width'];
-	    $this->_dest_h = (int)$input['height'];
-	  }
-	else if ( isset($input['w']) )
-	  {
-	    $this->_dest_w = (int)$input['w'];
-	    $this->_dest_h = (int)$input['h'];
-	  }
-	if( isset($input['color']) && $input['color'] != '')
-	  {
-	    $input['color'] = strtolower($input['color']);
-	    if( $input['color'] != 'transparent' )
-	      {
-		list($this->_r,$this->_g,$this->_b) = cgsi_utils::color_to_rgb(trim($input['color']));
-	      }
-	    else
-	      {
-		$this->_transparent = 1;
-	      }
-	  }
-	if( isset($input['alpha']) )
-	  {
-	    $this->_alpha = (int)$input['alpha'];
-	  }
+    if( cge_array::is_hash($input) ) {
+      if( isset($input['width']) ) {
+	$this->_dest_w = (int)$input['width'];
+	$this->_dest_h = (int)$input['height'];
       }
-    else if( is_array($input)  )
-      {
-	if( count($input) >= 2 )
-	  {
-	    $this->_dest_w = (int)trim($input[0]);
-	    $this->_dest_h = (int)trim($input[1]);
-	    if( count($input) >= 3 )
-	      {
-		if( $input[2] != '' )
-		  {
-		    $input[2] = strtolower($input[2]);
-		    if( $input[2] != 'transparent' )
-		      {
-			list($this->_r,$this->_g,$this->_b) = cgsi_utils::color_to_rgb(trim($input[2]));
-		      }
-		    else
-		      {
-			$this->_transparent = 1;
-		      }
-		  }
-		if( count($input) >= 4 )
-		  {
-		    if( $input[3] != '' ) $this->_alpha = (int)$input[3];
-		  }
-	      }
-	  }
+      else if ( isset($input['w']) ) {
+	$this->_dest_w = (int)$input['w'];
+	$this->_dest_h = (int)$input['h'];
       }
+      if( isset($input['color']) && $input['color'] != '') {
+	$input['color'] = strtolower($input['color']);
+	if( $input['color'] != 'transparent' ) {
+	  list($this->_r,$this->_g,$this->_b) = cgsi_utils::color_to_rgb(trim($input['color']));
+	}
+	else {
+	  $this->_transparent = 1;
+	}
+      }
+      if( isset($input['alpha']) ) $this->_alpha = (int)$input['alpha'];
+    }
+    else if( is_array($input)  ) {
+      if( count($input) >= 2 ) {
+	$this->_dest_w = (int)trim($input[0]);
+	$this->_dest_h = (int)trim($input[1]);
+	if( count($input) >= 3 ) {
+	  if( $input[2] != '' ) {
+	    $input[2] = strtolower($input[2]);
+	    if( $input[2] != 'transparent' ) {
+	      list($this->_r,$this->_g,$this->_b) = cgsi_utils::color_to_rgb(trim($input[2]));
+	    }
+	    else {
+	      $this->_transparent = 1;
+	    }
+	  }
+	  if( count($input) >= 4 ) if( $input[3] != '' ) $this->_alpha = (int)$input[3];
+	}
+      }
+    }
 
     $this->_dest_w = cgsi_utils::trim_to_device('width',$this->_dest_w);
     $this->_dest_h = cgsi_utils::trim_to_device('height',$this->_dest_h);
 
     // todo: convert color name into rgb.
-    if( $this->_dest_h <= 0 || $this->_dest_w <= 0 || $this->_alpha < 0 || $this->_alpha > 127 )
-      {
-	throw new Exception('Invalid values specified for Croptofit filter constructor');
-      }
+    if( $this->_dest_h <= 0 || $this->_dest_w <= 0 || $this->_alpha < 0 || $this->_alpha > 127 ) {
+      throw new Exception('Invalid values specified for Croptofit filter constructor');
+    }
   }
 
 
@@ -124,63 +105,49 @@ class CGImage_Resizetofit_Filter extends CGImageFilterBase
     $this->_dest_h = min($this->_dest_h,$src['height']);
 
     // quick optimization (nothing to do)
-    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] )
-      {
-	return $src;
-      }
+    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] ) return $src;
 
     // create our destination image.
-    $_dest = new CGImageBase(array('image/png',$this->_dest_w,$this->_dest_h));
+    $_dest = new CGImageBase(array($src['type'],$this->_dest_w,$this->_dest_h));
     imagealphablending($_dest['rsrc'], TRUE);
 
     // fill our image with a color (or transparent)
     $color = '';
-    if( $this->_transparent )
-      {
-	// find a random unused color for transparency.
-	$found = 0;
-	while( !$found )
-	  {
-	    $this->_r = rand(0,255);
-	    $this->_g = rand(0,255);
-	    $this->_b = rand(0,255);
-	    if( imagecolorexact($src['rsrc'],$this->_r,$this->_g,$this->_b) != -1 )
-	      {
-		$found = true;
-	      }
-	  }
+    if( $this->_transparent ) {
+      // find a random unused color for transparency.
+      $found = 0;
+      while( !$found ) {
+	$this->_r = rand(0,255);
+	$this->_g = rand(0,255);
+	$this->_b = rand(0,255);
+	if( imagecolorexact($src['rsrc'],$this->_r,$this->_g,$this->_b) != -1 ) $found = true;
+      }
 
-	$color = imagecolorallocatealpha($_dest['rsrc'], $this->_r, $this->_g, $this->_b, 127);
-	imagecolortransparent($_dest['rsrc'],$color);
-      }
-    else
-      {
-	$color = imagecolorallocatealpha($_dest['rsrc'], $this->_r, $this->_g, $this->_b, $this->_alpha);
-      }
+      $color = imagecolorallocatealpha($_dest['rsrc'], $this->_r, $this->_g, $this->_b, 127);
+      imagecolortransparent($_dest['rsrc'],$color);
+    }
+    else {
+      $color = imagecolorallocatealpha($_dest['rsrc'], $this->_r, $this->_g, $this->_b, $this->_alpha);
+    }
     imagefill($_dest['rsrc'], 0, 0, $color);
 
-    if( $this->_dest_w > $this->_dest_h )
-      {
-	// height is greater... 
-	$new_h = $this->_dest_h;
-	$new_w = round(($new_h / $src['height']) * $src['width'], 0);
-      }
-    else
-      {
-	// width is greater.
-	$new_w = $this->_dest_w;
-	$new_h = round(($new_w / $src['width']) * $src['height'], 0);
-      }
+    if( $this->_dest_w > $this->_dest_h ) {
+      // height is greater... 
+      $new_h = $this->_dest_h;
+      $new_w = round(($new_h / $src['height']) * $src['width'], 0);
+    }
+    else {
+      // width is greater.
+      $new_w = $this->_dest_w;
+      $new_h = round(($new_w / $src['width']) * $src['height'], 0);
+    }
 
     $x0 = (int)(($this->_dest_w - $new_w) / 2);
     $y0 = (int)(($this->_dest_h - $new_h) / 2);
 
     // resize the big image into the temporary transparent image
     $res = imagecopyresampled($_dest['rsrc'],$src['rsrc'],$x0,$y0,0,0,$new_w,$new_h,$src['width'],$src['height']);
-    if( $res === FALSE )
-      {
-	throw new Exception('Resizetofit - stage 1 - failed');
-      }
+    if( $res === FALSE ) throw new Exception('Resizetofit - stage 1 - failed');
     return $_dest;
   }
 
